@@ -1,10 +1,10 @@
 
-from .old import *
-from . import old
-
 from .core import *
 from . import core
 
+from .quick import *
+from . import quick
+
 __all__ = [
     'bar',
     'figure',
@@ -12,3 +12,5 @@ __all__ = [
     'plot',
     'point',
 ]
+
+
